@@ -1,14 +1,14 @@
 from dataclasses import dataclass
-from src.dataclasses.asset_data import AssetData
+from src.dataclasses.content_data import ContentData
 
 
 @dataclass
 class Image:
     """Basic image class"""
 
-    data: AssetData
+    data: ContentData
 
     def render(self, data):
         content = data.content
-        rendered_image = f'![{self.data.alt}]({self.data.filename})'
+        rendered_image = f'![{self.data.title}]({self.data.filename})'
         return content.replace(self.data.placeholder, rendered_image)
